pub struct Diagnostic {
pub severity: Severity,
pub location: Option<Location>,
pub message: String,
}Expand description
One problem found while loading a file.
Fields
severity: SeverityError or warning.
location: Option<Location>Where the problem is, when it can be pinned to a place in a file.
message: StringWhat is wrong and, where possible, how to fix it.
Implementations