pub enum KeyKind {
Press,
Repeat,
Release,
}Expand description
Whether a key went down, auto-repeated or came up.
Variants
Press
The key went down.
Repeat
The key is held and the terminal repeats it (only reported by terminals with the kitty keyboard protocol).
Release
The key came up (kitty keyboard protocol only).