pub enum ClipboardEvent {
Copied(String),
Pasted(String),
}Expand description
Something that happened on the clipboard, delivered to
App::clipboard.
Variants
Copied(String)
A widget or a mouse selection copied this text.
Pasted(String)
This text was pasted (from the terminal, with the paste key or from a Paste menu entry)
and no focused widget took it.