pub struct LayoutProps {
pub width: Length,
pub height: Length,
pub padding: Padding,
pub gap: u16,
pub justify: Align,
pub align: Align,
}Expand description
Layout properties of a node.
Fields
width: LengthWidth.
height: LengthHeight.
padding: PaddingSpace kept free inside the node.
gap: u16Cells between children of a row or column.
justify: AlignPlacement of children along the main axis of a row or column, or both axes of a stack.
align: AlignPlacement of children across the main axis.