pub enum DurationUnit {
Hours,
Minutes,
Seconds,
}Expand description
A unit of a length of time.
Variants
Hours
Hours: h, hour, sa, saat and the other words of the language files.
Minutes
Minutes: min, m, dk, dakika and the other words of the language files.
Seconds
Seconds: s, sec, sn, saniye and the other words of the language files.