pub enum Language {
Rust,
Toml,
Shell,
Plain,
}Expand description
A language CodeView can colour.
Variants
Rust
Rust source.
Toml
TOML files such as themes and locales.
Shell
Shell scripts in bash syntax, such as a PKGBUILD or a package’s .install file.
Plain
No highlighting.
Implementations
Sourceimpl Language
impl Language
Sourcepub fn from_tag(tag: &str) -> Self
pub fn from_tag(tag: &str) -> Self
The language for a fenced code block tag such as rust or toml.
Sourcepub fn from_file_name(name: &str) -> Self
pub fn from_file_name(name: &str) -> Self
The language of the file named name (a bare name or a path): .rs is Rust, .toml
is TOML, .sh, .bash, .zsh, .install and a PKGBUILD are shell scripts, and
anything else is plain text.