pub enum LineTone {
Accent,
Warning,
}Expand description
The tone of highlighted lines; see CodeView::highlight_lines.
Variants
Accent
A line to look at, such as the one a “go to line” reached: an accent tint and the pillar.
Warning
A line worth a careful look, such as a finding of a review: a warning tint and the warning icon.