pub enum NameFor {
File,
Folder,
Rename(String),
}Expand description
What the name the dialog asks for is for.
Variants
File
A new, empty file.
Folder
A new, empty folder.
Rename(String)
The entry of this key, which keeps its place and takes the new name.