#[non_exhaustive]pub enum ClipboardKey {
Cut,
Copy,
Paste,
}Expand description
One of the three keys that cut, copy and paste, for a node to claim with
NodeMut::on_clipboard.
They are the keys a text field cuts, copies and pastes its text with, which a list of other things, such as a file manager’s rows, gives its own meaning to while it has focus.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cut
Ctrl+X, the key a text field cuts with.
Copy
The keys of the global keymap action copy, Ctrl+C unless rebound.
Paste
The keys of the global keymap action paste, Ctrl+V unless rebound.