pub enum DurationError {
Empty,
Character(char),
UnknownUnit(String),
BadNumber(String),
MissingNumber(String),
MissingUnit(String),
RepeatedUnit(DurationUnit),
BadClock(String),
TooLarge,
}Expand description
Why a written length of time could not be read. message says it in the
active language.
Variants
Empty
Nothing but spaces.
Character(char)
A character that has no place in a length of time, such as - or /.
UnknownUnit(String)
A word that is no unit of time in any known language, such as days.
BadNumber(String)
A number that cannot be read, such as 1.2.3.
MissingNumber(String)
A unit with no number before it, such as the h of h 30.
MissingUnit(String)
A number with no unit that cannot take one from its place, such as the 30 of 1 30 min.
RepeatedUnit(DurationUnit)
A unit written twice, such as 1 h 2 h.
BadClock(String)
Text with a colon that is not h:mm or h:mm:ss with minutes and seconds under 60.
TooLarge
Longer than 99 hours, 59 minutes and 59 seconds.
Implementations